# IfcOptimizeRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**floating_point_reduction** | **int** | Precision of geometries. 6 is micrometre, 9 is nanometre, ect... | [optional]  if omitted the server will use the default value of 9
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


